###################################################
### chunk number 1: rarAnalysis1
###################################################
#line 27 "d:/Rcompile/CRANpkg/local/2.12/rtfbs/inst/doc/vignette.Rnw"

require("rtfbs")
# extract sequence and position weight matrix files from RTFBS package
exampleArchive <- system.file("extdata", "NRSF.zip", package="rtfbs")
unzip(exampleArchive, c("input.fas", "pwm.meme"))
# read the position weight matrices from meme text formatted file
pwm <- read.pwm("pwm.meme")
# delete the file since we now have the PWMs in memory
unlink("pwm.meme")


###################################################
### chunk number 2: rarAnalysis2
###################################################
#line 46 "d:/Rcompile/CRANpkg/local/2.12/rtfbs/inst/doc/vignette.Rnw"
# read in the sequences
ms <- read.ms("input.fas")
# delete the file since we now have the sequences in memory
unlink("input.fas")


###################################################
### chunk number 3: rarAnalysis3
###################################################
#line 61 "d:/Rcompile/CRANpkg/local/2.12/rtfbs/inst/doc/vignette.Rnw"

msSplit <- split.ms(ms, 500)


###################################################
### chunk number 4: rarAnalysis4
###################################################
#line 71 "d:/Rcompile/CRANpkg/local/2.12/rtfbs/inst/doc/vignette.Rnw"

msGroups <- groupByGC.ms(msSplit, 4);


###################################################
### chunk number 5: rarAnalyis5
###################################################
#line 86 "d:/Rcompile/CRANpkg/local/2.12/rtfbs/inst/doc/vignette.Rnw"

markovModels <- list()
for (i in 1:length(msGroups)) 
  markovModels[[i]] <- build.mm(msGroups[[i]], 3)


###################################################
### chunk number 6: rarAnalysis6
###################################################
#line 97 "d:/Rcompile/CRANpkg/local/2.12/rtfbs/inst/doc/vignette.Rnw"

listOfScoresReal <- list()
for (i in 1:length(msGroups))
  listOfScoresReal[[i]] <- score.ms(msGroups[[i]], pwm, markovModels[[i]])


###################################################
### chunk number 7: rarAnalysis8
###################################################
#line 125 "d:/Rcompile/CRANpkg/local/2.12/rtfbs/inst/doc/vignette.Rnw"

simulatedSeqs <- list()
for (i in 1:length(msGroups)) 
  simulatedSeqs[[i]] <- simulate.ms(markovModels[[i]], 500000)


###################################################
### chunk number 8: rarAnalysis9
###################################################
#line 135 "d:/Rcompile/CRANpkg/local/2.12/rtfbs/inst/doc/vignette.Rnw"

listOfScoresSimulated <- list()
for (i in 1:length(msGroups))
  listOfScoresSimulated[[i]] <- score.ms(simulatedSeqs[[i]], pwm, markovModels[[i]])


###################################################
### chunk number 9: rarAnalysis10
###################################################
#line 146 "d:/Rcompile/CRANpkg/local/2.12/rtfbs/inst/doc/vignette.Rnw"

fdrMap <- list()
for (i in 1:length(msGroups))
  fdrMap[[i]] <- calc.fdr(msGroups[[i]], listOfScoresReal[[i]], 
                          simulatedSeqs[[i]], listOfScoresSimulated[[i]])


###################################################
### chunk number 10: Plot
###################################################
#line 160 "d:/Rcompile/CRANpkg/local/2.12/rtfbs/inst/doc/vignette.Rnw"

plot.fdr(fdrMap, col=rainbow(4))


###################################################
### chunk number 11: rarAnalysis11
###################################################
#line 173 "d:/Rcompile/CRANpkg/local/2.12/rtfbs/inst/doc/vignette.Rnw"

bindingSites <- data.frame()
for (i in 1:length(msGroups)) {
  bindingSites <- rbind(bindingSites,
                        output.sites(listOfScoresReal[[i]],
                                     fdrScoreMap=fdrMap[[i]],
                                     fdrThreshold=0.1))
}


